@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::AR::Conll2007;
 use strict;
 use warnings;
-our $VERSION = '3.004';
+our $VERSION = '3.005';
 
 use utf8;
 use open ':utf8';
@@ -75,9 +75,9 @@ sub _create_atoms
             # interjection
             'I-' => ['pos' => 'int'],
             # abbreviation
-            'Y-' => ['abbr' => 'abbr'],
+            'Y-' => ['abbr' => 'yes'],
             # typo
-            'T-' => ['typo' => 'typo'],
+            'T-' => ['typo' => 'yes'],
             # punctuation (not used in UMH subcorpus)
             'G-' => ['pos' => 'punc'],
             # unknown tokens etc. (former X?)
@@ -89,8 +89,8 @@ sub _create_atoms
         },
         'encode_map' =>
 
-            { 'abbr' => { 'abbr' => 'Y-',
-                          '@'    => { 'typo' => { 'typo' => 'T-',
+            { 'abbr' => { 'yes' => 'Y-',
+                          '@'    => { 'typo' => { 'yes' => 'T-',
                                                   '@'    => { 'numtype' => { ''  => { 'pos' => { 'noun' => { 'prontype' => { ''    => { 'nountype' => { 'prop' => 'Z-',
                                                                                                                                                         '@'    => 'N-' }},
                                                                                                                              'dem' => 'SD',
@@ -581,7 +581,7 @@ Lingua::Interset::Tagset::AR::Conll2007 - Driver for the Arabic tagset of the Co
 
 =head1 VERSION
 
-version 3.004
+version 3.005
 
 =head1 SYNOPSIS
 
