@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::CA::Conll2009;
 use strict;
 use warnings;
-our $VERSION = '3.004';
+our $VERSION = '3.005';
 
 use utf8;
 use open ':utf8';
@@ -107,7 +107,7 @@ sub _create_atoms
             'ordinal'       => ['numtype' => 'ord'],
             # types of pronouns
             'personal'      => ['prontype' => 'prs'],
-            'possessive'    => ['prontype' => 'prs', 'poss' => 'poss'],
+            'possessive'    => ['prontype' => 'prs', 'poss' => 'yes'],
             'article'       => ['prontype' => 'art'],
             'demonstrative' => ['prontype' => 'dem'],
             'interrogative' => ['prontype' => 'int'],
@@ -145,7 +145,7 @@ sub _create_atoms
         },
         'encode_map' =>
         {
-            'pos' => { 'noun' => { 'poss' => { 'poss' => 'possessive',
+            'pos' => { 'noun' => { 'poss' => { 'yes' => 'possessive',
                                                '@'    => { 'prontype' => { 'prs' => 'personal',
                                                                            'dem' => 'demonstrative',
                                                                            'int' => 'interrogative',
@@ -155,7 +155,7 @@ sub _create_atoms
                                                                            '@'   => { 'nountype' => { 'com'  => 'common',
                                                                                                       'prop' => 'proper',
                                                                                                       '@'    => { 'other/postype' => { 'currency' => 'currency' }}}}}}}},
-                       'adj'  => { 'poss' => { 'poss' => 'possessive',
+                       'adj'  => { 'poss' => { 'yes' => 'possessive',
                                                '@'    => { 'prontype' => { 'prs' => 'personal',
                                                                            'art' => 'article',
                                                                            'dem' => 'demonstrative',
@@ -830,7 +830,7 @@ Lingua::Interset::Tagset::CA::Conll2009 - Driver for the Catalan tagset of the C
 
 =head1 VERSION
 
-version 3.004
+version 3.005
 
 =head1 SYNOPSIS
 
