@@ -8,7 +8,7 @@
 package Lingua::Interset::Tagset::FO::Setur;
 use strict;
 use warnings;
-our $VERSION = '3.004';
+our $VERSION = '3.005';
 
 use utf8;
 use open ':utf8';
@@ -69,16 +69,16 @@ sub _create_atoms
             # interjection
             'I' => ['pos' => 'int'],
             # foreign word
-            'F' => ['foreign' => 'foreign'],
+            'F' => ['foreign' => 'yes'],
             # unanalyzed word
             'X' => [],
             # abbreviation
-            'T' => ['abbr' => 'abbr']
+            'T' => ['abbr' => 'yes']
         },
         'encode_map' =>
         {
-            'abbr' => { 'abbr' => 'T',
-                        '@'    => { 'foreign' => { 'foreign' => 'F',
+            'abbr' => { 'yes' => 'T',
+                        '@'    => { 'foreign' => { 'yes' => 'F',
                                                    '@'       => { 'pos' => { 'noun' => { 'prontype' => { ''  => 'S',
                                                                                                          '@' => 'P' }},
                                                                              'adj'  => 'A',
@@ -864,7 +864,7 @@ Lingua::Interset::Tagset::FO::Setur - Driver for the Faroese tagset provided by
 
 =head1 VERSION
 
-version 3.004
+version 3.005
 
 =head1 SYNOPSIS
 
