@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::LA::Itconll;
 use strict;
 use warnings;
-our $VERSION = '3.004';
+our $VERSION = '3.005';
 
 use utf8;
 use open ':utf8';
@@ -67,7 +67,7 @@ sub _create_atoms
             # invariable
             '4'    => ['pos' => 'part'], # adv|adp|conj|part|int
             # pseudo-lemma (e.g. abbreviation: corp., art., boet.)
-            '5'    => ['abbr' => 'abbr'],
+            '5'    => ['abbr' => 'yes'],
             # punctuation
             'Punc' => ['pos' => 'punc']
         },
@@ -135,7 +135,7 @@ sub _create_atoms
             # prepositional (always or not) particle (examples: ad, contra, in, cum, per)
             'S4' => ['pos' => 'adp', 'adpostype' => 'prep', 'other' => {'flexcat' => 'preppart'}],
             # pseudo-lemma / abbreviation
-            '5'  => ['abbr' => 'abbr'],
+            '5'  => ['abbr' => 'yes'],
             # pseudo-lemma / number
             'G5' => ['pos' => 'num', 'numform' => 'digit'],
             # punctuation
@@ -207,7 +207,7 @@ sub _create_atoms
                        'punc' => 'Punc',
                        '@'    => { 'other/flexcat' => { 'invar'    => 'O4',
                                                         'preppart' => 'S4',
-                                                        '@'        => { 'abbr' => { 'abbr' => '5',
+                                                        '@'        => { 'abbr' => { 'yes' => '5',
                                                                                     '@'    => 'O4' }}}}}
         }
     );
@@ -476,12 +476,12 @@ sub _create_atoms
             # III variation of wordform (illuc)
             'varC' => ['variant' => '3'],
             # author mistake, or bad reading? (quod)
-            'varx' => ['typo' => 'typo'],
-            'varX' => ['typo' => 'typo']
+            'varx' => ['typo' => 'yes'],
+            'varX' => ['typo' => 'yes']
         },
         'encode_map' =>
         {
-            'typo' => { 'typo' => 'varX',
+            'typo' => { 'yes' => 'varX',
                         '@'    => { 'variant' => { ''  => '',
                                                    '1' => 'varA',
                                                    '2' => 'varB',
@@ -2303,7 +2303,7 @@ Lingua::Interset::Tagset::LA::Itconll - Driver for the tagset of the Index Thomi
 
 =head1 VERSION
 
-version 3.004
+version 3.005
 
 =head1 SYNOPSIS
 
